Englewood
=========

Englewood is a python library for generating maps from maps.

Currently only dot-density maps can be generated, but hopefully other types of maps (contigous and non-contigous cartograms, scaled centroids markers, etc) will follow.

Installation
------------

It's easy!

::

    pip install englewood

Usage
-----

See demo.py for an example of how to generate a dot density map.

Note: data for the demo is sourced from `Reshaping Chicago's political map <http://media.apps.chicagotribune.com/ward-redistricting/index.html>`_. The Chicago Wards shapefile the City of Chicago's `data portal <http://data.cityofchicago.org/Government/Boundaries-Wards/bhcv-wqkf>`_.

Authors
-------

* Christopher Groskopf (`@onyxfish <http://twitter.com/onyxfish>`_)

License
-------

MIT

